@@ -117,13 +117,16 @@ def register() -> None:
 
     _add_directive("autosummary", autosummary.Autosummary)
     _add_directive("contents", parts.Contents)
+    _add_directive("currentmodule", sphinx.domains.python.PyCurrentModule)
     _add_directive("deprecated", sphinx.directives.other.VersionChange, raw=False)
     _add_directive("figure", directives.images.Figure, raw=False)
+    _add_directive("function", sphinx.domains.python.PyFunction)
     _add_directive("image", directives.images.Image)
     _add_directive("include", directives.misc.Include)
     _add_directive("list-table", directives.tables.ListTable, raw=False)
     _add_directive("literalinclude", sphinx.directives.code.LiteralInclude)
     _add_directive("math", directives.body.MathBlock)
+    _add_directive("py:function", sphinx.domains.python.PyFunction)
     _add_directive("raw", directives.misc.Raw)
     _add_directive("rst-class", sphinx.directives.other.Class)
     _add_directive("seealso", sphinx.directives.other.SeeAlso, raw=False)
